@@ -125,7 +125,14 @@ async def start_gateway(descriptor: FileDescriptor, port: int = 7070):
     app.add_exception_handler(HTTPException, http_exception)
     app.add_middleware(AccessLogMiddleware)
     app.add_middleware(PrometheusMiddleware)
-    app.add_middleware(CORSMiddleware, allow_origins=['*'], allow_methods=['*'])
+    app.add_middleware(
+      CORSMiddleware,
+      allow_origins=["*"],
+      allow_headers=["*"],
+      allow_methods=["*"],
+      expose_headers=["X-Status"],
+      allow_credentials=True,
+    )
     app.add_exception_handler(HTTPException, http_exception)
     app.add_route("/metrics/", metrics)
     channel = insecure_channel('localhost:8080')
